import logging

from pylons import config

import ckan.plugins as p
import ckan.plugins.toolkit as tk


def get_api_base_url():

    return config.get('open_govdata.api_url_prefix') or 'http://www.open-governmentdata.org/'


class OpenGovDataCustomFieldsPlugin(p.SingletonPlugin,
        tk.DefaultDatasetForm):
    p.implements(p.IDatasetForm)
    p.implements(p.IConfigurer)

    # Declare that this plugin will implement ITemplateHelpers.
    p.implements(p.ITemplateHelpers)

    def create_package_schema(self):
        # let's grab the default schema in our plugin
        schema = super(OpenGovDataCustomFieldsPlugin, self).create_package_schema()
        #our custom field
        schema.update({
            'frequency_of_update': [tk.get_validator('ignore_missing'),
                            tk.get_converter('convert_to_extras')]})
        schema.update({
            'spatial': [tk.get_validator('ignore_missing'),
                            tk.get_converter('convert_to_extras')]})

        schema.update({
            'copyright': [tk.get_validator('ignore_missing'),
                        tk.get_converter('convert_to_extras')]})

        ## Resource Copyright
        # schema['resources'].update({
        #     'copyright': [tk.get_validator('ignore_missing'),
        #                 tk.get_converter('convert_to_extras')]})

        return schema

    def update_package_schema(self):
        schema = super(OpenGovDataCustomFieldsPlugin, self).update_package_schema()
        #our custom field
        schema.update({
            'frequency_of_update': [tk.get_validator('ignore_missing'),
                            tk.get_converter('convert_to_extras')]})
        schema.update({
            'spatial': [tk.get_validator('ignore_missing'),
                            tk.get_converter('convert_to_extras')]})

        schema.update({
            'copyright': [tk.get_validator('ignore_missing'),
                        tk.get_converter('convert_to_extras')]})

        ## Resource Copyright
        # schema['resources'].update({
        #     'copyright': [tk.get_validator('ignore_missing'),
        #                 tk.get_converter('convert_to_extras')]})

        return schema

    def show_package_schema(self):
        schema = super(OpenGovDataCustomFieldsPlugin, self).show_package_schema()
        schema.update({
            'frequency_of_update': [tk.get_converter('convert_from_extras'),
                            tk.get_validator('ignore_missing')]})
        schema.update({
            'spatial': [tk.get_converter('convert_from_extras'),
                            tk.get_validator('ignore_missing')]})

        schema.update({
            'copyright': [tk.get_converter('convert_from_extras'),
                        tk.get_validator('ignore_missing')]})

        ## Resource Copyright
        # schema['resources'].update({
        #     'copyright': [tk.get_converter('convert_from_extras'),
        #                 tk.get_validator('ignore_missing')]})

        return schema

    def is_fallback(self):
        # Return True to register this plugin as the default handler for
        # package types not handled by any other IDatasetForm plugin.
        return True

    def package_types(self):
        # This plugin doesn't handle any special package types, it just
        # registers itself as the default (above).
        return []

    def update_config(self, config_):
        tk.add_template_directory(config_, 'templates')

        # Add this plugin's public dir to CKAN's extra_public_paths, so
        # that CKAN will use this plugin's custom static files.
        tk.add_public_directory(config_, 'public')


        tk.add_resource('public/base/javascript', 'open_govdata_org_override')

    def get_helpers(self):
        '''Register the most_popular_groups() function above as a template
        helper function.

        '''
        # Template helper function names should begin with the name of the
        # extension they belong to, to avoid clashing with functions from
        # other extensions.
        return {'get_api_base_url': get_api_base_url}

